"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const cleanUpFiles_1 = __importDefault(require("./files/cleanUpFiles"));
const fileLists_1 = __importDefault(require("./files/fileLists"));
const jest_1 = require("./files/jest");
const string_1 = require("./helpers/string");
const normalize_1 = __importDefault(require("./normalize"));
const outputs_1 = require("./outputs");
const createRunners_1 = __importDefault(require("./runner/createRunners"));
const runTests_1 = __importDefault(require("./runner/runTests"));
const settings_1 = require("./threshold/settings");
exports.getFileListsCallback = (rootDirectory) => {
    if (typeof rootDirectory === 'string') {
        return (path) => string_1.cleanFileFromRootPath(path, rootDirectory);
    }
    return () => '';
};
const appExecute = async (argvArray, argvObject, cwdDirectory, cpuCount, cpuUsed) => {
    if (typeof argvObject.config !== 'string') {
        throw new TypeError('The Argument "--config" is missing');
    }
    const jestConfig = await jest_1.getJestConfig(cwdDirectory, argvObject.config);
    const { thresholdLimits, ...config } = normalize_1.default(jestConfig, cwdDirectory);
    const [files, testFiles, runners] = await Promise.all([
        fileLists_1.default([config.rootDir], config.collectCoverageFrom, exports.getFileListsCallback()),
        fileLists_1.default(config.roots, config.testMatch, exports.getFileListsCallback(config.rootDir)),
        createRunners_1.default(config, cpuUsed),
    ]);
    const cleanedUpFiles = cleanUpFiles_1.default(files, testFiles, config);
    outputs_1.outputStatus(cleanedUpFiles.length, testFiles.length, cpuCount, cpuUsed);
    const thresholdData = await runTests_1.default(testFiles, runners, argvArray, argvObject.config, config);
    return { cleanedUpFiles, thresholdData, thresholdLimits: { ...settings_1.thresholdDefaultLimits, ...thresholdLimits } };
};
exports.default = appExecute;
