"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const fs_1 = require("fs");
const path_1 = require("path");
const fileSystems_1 = require("./fileSystems");
exports.readJsonFile = async (filename) => {
    const isReadable = await fileSystems_1.hasFileAccess(filename, fs_1.constants.R_OK);
    if (!isReadable) {
        throw new Error(`File ${filename} is not readable`);
    }
    return new Promise((resolve, reject) => {
        fs_1.readFile(filename, { encoding: 'utf8' }, (error, data) => {
            if (error) {
                return reject(error);
            }
            try {
                return resolve(JSON.parse(data));
            }
            catch (error_) {
                return reject(error_);
            }
        });
    });
};
exports.writeJsonFile = async (filename, data) => {
    const isWritable = await fileSystems_1.hasFileAccess(path_1.dirname(filename), fs_1.constants.W_OK);
    if (!isWritable) {
        throw new Error(`File ${filename} is not writable`);
    }
    return new Promise((resolve, reject) => {
        fs_1.writeFile(filename, JSON.stringify(data, undefined, 2), { encoding: 'utf8' }, (error) => error ? reject(error) : resolve());
    });
};
