"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const path_1 = require("path");
const is_1 = require("./helpers/is");
const settings_1 = require("./threshold/settings");
exports.getCoverageDirectory = (config) => typeof config.coverageDirectory === 'string' ? config.coverageDirectory : '.coverage';
exports.getCoveragePathIgnorePatterns = (config) => Array.isArray(config.coveragePathIgnorePatterns) ? config.coveragePathIgnorePatterns : [];
exports.getRootDirectory = (config, cwdDirectory) => typeof config.rootDir === 'string' ? path_1.normalize(config.rootDir) : cwdDirectory;
exports.getRoots = (config, rootDirectory) => {
    if (Array.isArray(config.roots)) {
        return config.roots.map((path) => path.replace('<rootDir>', path_1.normalize(rootDirectory)));
    }
    return [rootDirectory];
};
exports.getThresholdLimits = (config) => {
    const thresholdLimits = {};
    if (is_1.isGlobalThreshold(config.coverageThreshold)) {
        const threshold = config.coverageThreshold.global;
        settings_1.thresholdKeys.forEach((key) => {
            const value = threshold[key];
            if (typeof value === 'number') {
                thresholdLimits[key] = value;
            }
        });
    }
    return thresholdLimits;
};
const normalizeConfig = (config, cwdDirectory) => {
    if (!Array.isArray(config.testMatch)) {
        throw new TypeError('The jest config parameter "testMatch" is missing');
    }
    if (!Array.isArray(config.collectCoverageFrom)) {
        throw new TypeError('The jest config parameter "collectCoverageFrom" is missing');
    }
    // eslint-disable-next-line unicorn/prevent-abbreviations
    const rootDir = exports.getRootDirectory(config, cwdDirectory);
    const roots = exports.getRoots(config, rootDir);
    const testMatch = config.testMatch;
    const collectCoverageFrom = config.collectCoverageFrom;
    const coverageDirectory = exports.getCoverageDirectory(config);
    const coveragePathIgnorePatterns = exports.getCoveragePathIgnorePatterns(config);
    const thresholdLimits = exports.getThresholdLimits(config);
    return {
        ...config,
        testMatch,
        rootDir,
        roots,
        collectCoverage: true,
        collectCoverageFrom,
        coverageDirectory,
        coverageReporters: ['json-summary'],
        coverageThreshold: { global: { branches: 0, functions: 0, lines: 0, statements: 0 } },
        coveragePathIgnorePatterns,
        thresholdLimits,
    };
};
exports.default = normalizeConfig;
