"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
/* eslint-disable no-console */
const cli_progress_1 = require("cli-progress");
const table_1 = require("table");
const errors_1 = require("./helpers/errors");
const string_1 = require("./helpers/string");
const styling_1 = __importDefault(require("./helpers/styling"));
const createTableData_1 = __importDefault(require("./threshold/createTableData"));
const settings_1 = require("./threshold/settings");
exports.outputError = (error) => {
    var _a;
    if (error instanceof Error) {
        if (error instanceof errors_1.TestError) {
            console.error(styling_1.default('|> An error was thrown during testing!', 'red'));
            console.error(styling_1.default('|> ', 'red'));
            console.error(styling_1.default('|> Output', 'red'));
            console.error(styling_1.default('|> ', 'red'));
            console.error(string_1.mapPerLine(error.data, (line) => styling_1.default('|> ', 'red') + line));
        }
        else {
            console.error(string_1.mapPerLine((_a = error.stack, (_a !== null && _a !== void 0 ? _a : `Error: ${error.message}`)), (line) => styling_1.default('|> ', 'red') + line));
        }
    }
    else {
        console.error(error);
    }
    console.log('');
};
exports.outputMetrics = (status, runtime) => {
    const types = Object.keys(status);
    const maxChars = types.reduce((p, c) => Math.max(p, status[c]), 0).toString().length;
    console.log(styling_1.default('Summary', 'underline'));
    console.log(`├─ Success: ${styling_1.default(string_1.padLeft(status.success.toString(), maxChars, ' '), 'green')}`);
    console.log(`└─ Error:   ${styling_1.default(string_1.padLeft(status.error.toString(), maxChars, ' '), 'red')}`);
    console.log('');
    console.log(`Runtime: ${runtime} (mm:ss)`);
    console.log('');
};
exports.outputProgress = (count) => {
    const bar = new cli_progress_1.SingleBar({
        format: `${styling_1.default('{bar}', 'red')} {percentage}% | {value}/{total} Files`,
        barCompleteChar: '\u2588',
        barIncompleteChar: '\u2591',
        hideCursor: true,
    });
    bar.start(count, 0);
    return {
        increment: () => bar.increment(),
        stop: () => {
            bar.stop();
            console.log('');
        },
    };
};
exports.outputStatus = (countFiles, countTestFiles, cpuCount, cpuUsed) => {
    console.log('');
    console.log(`CPU detected: ${styling_1.default(cpuCount, 'red')} (${styling_1.default(cpuUsed, 'red')} are used)`);
    console.log(`Files found:  ${styling_1.default(countFiles, 'red')} (${styling_1.default(countTestFiles, 'red')} with tests)`);
    console.log('');
};
exports.outputTable = (thresholds, thresholdLimits) => {
    const thresholdRows = createTableData_1.default(thresholds, thresholdLimits);
    console.log(table_1.table(thresholdRows, settings_1.tableConfig));
};
