"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const jest_1 = require("../files/jest");
const commons_1 = require("../helpers/commons");
const outputs_1 = require("../outputs");
const runnerEvaluation_1 = __importDefault(require("./runnerEvaluation"));
const runnerInitialization_1 = __importDefault(require("./runnerInitialization"));
const runTests = async (testFiles, runners, argvArray, configFile, config) => {
    let isPending = false;
    const bar = outputs_1.outputProgress(testFiles.length);
    const command = await jest_1.getJestFilename(config.rootDir);
    const thresholds = [];
    const data = {
        testFiles,
        argvArray,
        configFile,
        config,
        command,
        thresholds,
        barIncrement: bar.increment,
    };
    do {
        isPending = false;
        for (const runner of runners) {
            const isPendingEvaluation = await runnerEvaluation_1.default(runner, data);
            const isPendingInitialization = runnerInitialization_1.default(runner, data);
            isPending = isPending || isPendingEvaluation || isPendingInitialization;
        }
        if (isPending) {
            await commons_1.delay(250);
        }
    } while (testFiles.length > 0 || isPending);
    bar.stop();
    return thresholds;
};
exports.default = runTests;
