"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const json_1 = require("../files/json");
const is_1 = require("../helpers/is");
const string_1 = require("../helpers/string");
const settings_1 = require("./settings");
exports.getSummaryObject = (fileData, type) => {
    if (is_1.isObject(fileData)) {
        const data = fileData[type];
        return is_1.isSummary(data) ? data : undefined;
    }
    return undefined;
};
const extract = async (pathCoverage, testFile, config) => {
    const json = await json_1.readJsonFile(pathCoverage);
    const files = [];
    const testFileShort = string_1.cleanFileFromExtensions(testFile);
    for (const file of Object.keys(json)) {
        const fileShort = string_1.cleanFileFromRootPath(file, config.rootDir);
        if (string_1.cleanFileFromExtensions(fileShort) === testFileShort) {
            const threshold = { branches: 'ERROR', functions: 'ERROR', lines: 'ERROR', statements: 'ERROR' };
            const data = json[file];
            for (const type of settings_1.thresholdKeys) {
                const summary = exports.getSummaryObject(data, type);
                if (summary) {
                    threshold[type] = {
                        percent: summary.pct,
                        uncovered: summary.total - summary.covered,
                    };
                }
            }
            files.push({
                file: fileShort,
                threshold,
            });
        }
    }
    return files;
};
exports.default = extract;
