import { thresholdKeys } from './threshold/settings';
export declare type ExtendPromiseType<T> = {
    promise: Promise<T | Error>;
    isPending: () => boolean;
};
export declare type ArgvObjectType = {
    config?: string;
    [x: string]: unknown;
};
export declare type RunnerType = {
    configFile: string;
    coverageFile: string;
    test?: {
        file: string;
    } & ExtendPromiseType<string>;
};
export declare type RunnerEvaluationDataType = {
    thresholds: ThresholdGroupType[];
    config: JestConfigType;
    barIncrement: BarReturnType['increment'];
};
export declare type RunnerInitializationDataType = {
    testFiles: string[];
    argvArray: string[];
    configFile: string;
    config: JestConfigType;
    command: string;
};
export declare type RunnerDataType = RunnerEvaluationDataType & RunnerInitializationDataType;
export declare type BarReturnType = {
    increment: () => void;
    stop: () => void;
};
export declare type JestConfigType = {
    testMatch: string[];
    rootDir: string;
    roots: string[];
    collectCoverage: true;
    collectCoverageFrom: string[];
    coverageDirectory: string;
    coverageReporters: string[];
    coverageThreshold: {
        global: ThresholdType<number>;
    };
    coveragePathIgnorePatterns: string[];
    [x: string]: unknown;
};
export declare type CoverageSummaryType = {
    pct: number;
    total: number;
    covered: number;
};
export declare type ThresholdKeysType = typeof thresholdKeys[any];
export declare type ThresholdColorType = 'success' | 'error';
export declare type ThresholdErrorTypes = 'ERROR';
export declare type ThresholdValueType = {
    percent: number;
    uncovered: number;
} | ThresholdErrorTypes;
export declare type ThresholdRowType = string[];
export declare type ThresholdType<T = ThresholdValueType> = Record<ThresholdKeysType, T>;
export declare type ThresholdGroupType<T = ThresholdValueType> = {
    file: string;
    threshold: ThresholdType<T>;
    error?: unknown;
};
export declare type UnpackedPromise<T> = T extends Promise<infer U> ? U : T;
